{
    "$graph": [
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "biowardrobe2/star:v2.5.3a",
                    "dockerFile": "$import: ./dockerfiles/star-Dockerfile\n"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "File",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--genomeChainFiles"
                    },
                    "doc": "string: chain files for genomic liftover\n",
                    "id": "#star-genomegenerate.cwl/genome_chain_files"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--genomeChrBinNbits"
                    },
                    "doc": "int: =log2(chrBin), where chrBin is the size of the bins for genome\nstorage: each chromosome will occupy an integer number of bins\n",
                    "id": "#star-genomegenerate.cwl/genome_chr_bin_n_bits"
                },
                {
                    "type": "string",
                    "default": ".",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--genomeDir"
                    },
                    "doc": "Directory where genome index files are stored",
                    "id": "#star-genomegenerate.cwl/genome_dir"
                },
                {
                    "type": [
                        "File",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "inputBinding": {
                        "position": 1,
                        "itemSeparator": " ",
                        "prefix": "--genomeFastaFiles"
                    },
                    "doc": "string(s): path(s) to the fasta files with genomic sequences for genome\ngeneration, separated by spaces. Only used if runMode==genomeGenerate.\nThese files should be plain text FASTA files, they *cannot* be zipped.\n",
                    "id": "#star-genomegenerate.cwl/genome_fasta_files"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--genomeSAindexNbases"
                    },
                    "doc": "int: length (bases) of the SA pre-indexing string. Typically between 10 and\n15. Longer strings will use much more memory, but allow faster searches.\n",
                    "id": "#star-genomegenerate.cwl/genome_sa_index_n_bases"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--genomeSAsparseD"
                    },
                    "doc": "int>0: suffux array sparsity, i.e. distance between indices: use bigger\nnumbers to decrease needed RAM at the cost of mapping speed reduction\n",
                    "id": "#star-genomegenerate.cwl/genome_sa_sparse_d"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--genomeSuffixLengthMax"
                    },
                    "doc": "int: maximum length of the suffixes, has to be longer than read length. -1 = infinite.\n",
                    "id": "#star-genomegenerate.cwl/genome_suffix_length_max"
                },
                {
                    "type": [
                        "null",
                        "long"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--limitGenomeGenerateRAM"
                    },
                    "doc": "31000000000\nint>0: maximum available RAM (bytes) for genome generation\n",
                    "id": "#star-genomegenerate.cwl/limit_genome_generate_ram"
                },
                {
                    "type": [
                        "null",
                        "long"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--limitIObufferSize"
                    },
                    "doc": "150000000\nint>0: max available buffers size (bytes) for input/output, per thread\n",
                    "id": "#star-genomegenerate.cwl/limit_io_buffer_size"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--parametersFiles"
                    },
                    "doc": "string: name of a user-defined parameters file, \"-\": none. Can only be\ndefined on the command line.\n",
                    "id": "#star-genomegenerate.cwl/parameters_files"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--runDirPerm"
                    },
                    "doc": "User_RWX\nstring: permissions for the directories created at the run-time.\nUser_RWX ... user-read/write/execute\nAll_RWX  ... all-read/write/execute (same as chmod 777)\n",
                    "id": "#star-genomegenerate.cwl/run_dir_perm"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--sjdbGTFchrPrefix"
                    },
                    "doc": "string: prefix for chromosome names in a GTF file (e.g. 'chr' for using ENSMEBL annotations with UCSC genomes)\n",
                    "id": "#star-genomegenerate.cwl/sjdb_gtf_chr_prefix"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--sjdbGTFfeatureExon"
                    },
                    "doc": "exon\nstring: feature type in GTF file to be used as exons for building\ntranscripts\n",
                    "id": "#star-genomegenerate.cwl/sjdb_gtf_feature_exon"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--sjdbGTFfile"
                    },
                    "doc": "string: path to the GTF file with annotations\n",
                    "id": "#star-genomegenerate.cwl/sjdb_gtf_file"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--sjdbGTFtagExonParentGene"
                    },
                    "doc": "gene_id\nstring: tag name to be used as exons'' gene-parents (default \"gene_id\" works\nfor GTF files)\n",
                    "id": "#star-genomegenerate.cwl/sjdb_gtf_tag_exon_parent_gene"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--sjdbGTFtagExonParentTranscript"
                    },
                    "doc": "transcript_id\nstring: tag name to be used as exons' transcript-parents (default\n\"transcript_id\" works for GTF files)\n",
                    "id": "#star-genomegenerate.cwl/sjdb_gtf_tag_exon_parent_transcript"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--sjdbOverhang"
                    },
                    "doc": "default: 100\nint>0: length of the donor/acceptor sequence on each side of the junctions,\nideally = (mate_length - 1)\n",
                    "id": "#star-genomegenerate.cwl/sjdb_overhang"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--sysShell"
                    },
                    "doc": "string: path to the shell binary, preferrably bash, e.g. /bin/bash.\n- ... the default shell is executed, typically /bin/sh. This was reported to fail on some Ubuntu systems - then you need to specify path to bash.\n",
                    "id": "#star-genomegenerate.cwl/sys_shell"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--runThreadN"
                    },
                    "doc": "1\nint: number of threads to run STAR\n",
                    "id": "#star-genomegenerate.cwl/threads"
                }
            ],
            "baseCommand": [
                "STAR"
            ],
            "arguments": [
                "--runMode",
                "genomeGenerate"
            ],
            "doc": "Runs STAR genomeGenerated. Returns directory with index\n",
            "id": "#star-genomegenerate.cwl",
            "http://schema.org/name": "star-alignreads",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/Barski-lab/workflows/master/tools/star-alignreads.cwl",
            "http://schema.org/codeRepository": "https://github.com/Barski-lab/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/mainEntity": {
                "class": "http://schema.org/SoftwareSourceCode",
                "id": "#star-metadata.yaml",
                "http://schema.org/name": "STAR",
                "http://schema.org/about": "Aligns RNA-seq reads to a reference genome using uncompressed suffix arrays.\nSTAR has a potential for accurately aligning long (several kilobases) reads that\nare emerging from the third-generation sequencing technologies\n",
                "http://schema.org/url": "https://github.com/alexdobin/STAR",
                "http://schema.org/codeRepository": "https://github.com/alexdobin/STAR",
                "http://schema.org/license": [
                    "https://opensource.org/licenses/GPL-3.0"
                ],
                "http://schema.org/targetProduct": {
                    "class": "http://schema.org/SoftwareApplication",
                    "http://schema.org/softwareVersion": "v2.5.3a",
                    "http://schema.org/applicationCategory": "command line tool"
                },
                "http://schema.org/programmingLanguage": "C++",
                "http://schema.org/publication": [
                    {
                        "class": "http://schema.org/ScholarlyArticle",
                        "id": "#star-metadata.yaml/ 10.1093/bioinformatics/bts635",
                        "datePublished": "1 January 2013",
                        "http://schema.org/name": "STAR: ultrafast universal RNA-seq aligner",
                        "http://schema.org/author": [
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Alexander Dobin"
                            },
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Carrie A. Davis"
                            },
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Felix Schlesinger"
                            },
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Jorg Drenkow"
                            },
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Chris Zaleski"
                            },
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Sonali Jha"
                            },
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Philippe Batut"
                            },
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Mark Chaisson"
                            },
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Thomas R. Gingeras1"
                            }
                        ],
                        "http://schema.org/url": "https://academic.oup.com/bioinformatics/article/29/1/15/272537"
                    }
                ],
                "http://schema.org/discussionUrl": [
                    "https://github.com/alexdobin/STAR/issues"
                ],
                "http://schema.org/creator": [
                    {
                        "class": "http://schema.org/Organization",
                        "http://schema.org/name": "Cold Spring Harbor Laboratory, Cold Spring Harbor, NY, USA",
                        "http://schema.org/member": [
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Alexander Dobin",
                                "http://schema.org/description": "main author"
                            }
                        ]
                    }
                ]
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Andrey Kartashov",
                                            "http://schema.org/email": "mailto:Andrey.Kartashov@cchmc.org",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "id": "#0000-0001-9102-5681"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "chrNameLength.txt"
                    },
                    "id": "#star-genomegenerate.cwl/chr_name_length"
                },
                {
                    "type": "Directory",
                    "outputBinding": {
                        "glob": "$(inputs.genome_dir)"
                    },
                    "id": "#star-genomegenerate.cwl/indices"
                }
            ]
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "label": "GTF input file",
                    "format": "http://edamontology.org/format_2306",
                    "doc": "Annotation input file",
                    "id": "#main/annotation_gtf"
                },
                {
                    "type": "File",
                    "label": "Annotation file",
                    "format": "http://edamontology.org/format_3475",
                    "doc": "Tab-separated annotation file",
                    "id": "#main/annotation_tab"
                },
                {
                    "type": "File",
                    "label": "FASTA input file",
                    "format": "http://edamontology.org/format_1929",
                    "doc": "Reference genome input FASTA file",
                    "id": "#main/fasta"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "label": "Genome Chr Bin NBits",
                    "doc": "If you are using a genome with a large (>5,000) number of references (chrosomes/sca\ufb00olds),\nyou may need to reduce the --genomeChrBinNbits to reduce RAM consumption.\nThe following scaling is recommended: --genomeChrBinNbits = min(18,log2[max(GenomeLength/NumberOfReferences,ReadLength)]).\nFor example, for 3 gigaBase genome with 100,000 chromosomes/sca\ufb00olds, this is equal to 15.\n\ndefault: 18\n\nint: =log2(chrBin), where chrBin is the size of the bins for genome storage:\neach chromosome will occupy an integer number of bins.\nFor a genome with large number of contigs, it is recommended to scale this parameter\nas min(18, log2[max(GenomeLength/NumberOfReferences,ReadLength)]).\n",
                    "sd:layout": {
                        "advanced": true
                    },
                    "id": "#main/genome_chr_bin_n_bits"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "label": "Genome description",
                    "doc": "Genome description is used by web-ui to show description",
                    "sd:preview": {
                        "position": 2
                    },
                    "id": "#main/genome_description"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "label": "Genome details",
                    "doc": "Genome details",
                    "sd:preview": {
                        "position": 3
                    },
                    "id": "#main/genome_details"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "label": "Genome label",
                    "doc": "Genome label is used by web-ui to show label",
                    "sd:preview": {
                        "position": 1
                    },
                    "id": "#main/genome_label"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "label": "length of the SA pre-indexing string",
                    "doc": "For small genomes, the parameter --genomeSAindexNbases must to be scaled down, with a typical value of\nmin(14, log2(GenomeLength)/2 - 1). For example, for 1 megaBase genome, this is equal to 9,\nfor 100 kiloBase genome, this is equal to 7.\n\ndefault: 14\n\nint: length (bases) of the SA pre-indexing string.\nTypically between 10 and 15. Longer strings will use much more memory,\nbut allow faster searches. For small genomes, the parameter \u2013genomeSAindexNbases\nmust be scaled down to min(14, log2(GenomeLength)/2 - 1).\n",
                    "sd:layout": {
                        "advanced": true
                    },
                    "id": "#main/genome_sa_index_n_bases"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 2,
                    "label": "Use 2 to decrease needed RAM for STAR",
                    "doc": "int>0: suffux array sparsity, i.e. distance between indices: use bigger\nnumbers to decrease needed RAM at the cost of mapping speed reduction\n",
                    "sd:layout": {
                        "advanced": true
                    },
                    "id": "#main/genome_sa_sparse_d"
                },
                {
                    "type": [
                        "null",
                        "long"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--limitGenomeGenerateRAM"
                    },
                    "doc": "31000000000\nint>0: maximum available RAM (bytes) for genome generation\n",
                    "sd:layout": {
                        "advanced": true
                    },
                    "id": "#main/limit_genome_generate_ram"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "label": "Number of threads to run tools",
                    "doc": "Number of threads for those steps that support multithreading",
                    "sd:layout": {
                        "advanced": true
                    },
                    "id": "#main/threads"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "label": "Annotation file",
                    "format": "http://edamontology.org/format_3475",
                    "doc": "Tab-separated annotation file",
                    "outputSource": "#main/annotation_tab",
                    "id": "#main/annotation"
                },
                {
                    "type": "File",
                    "label": "Chromosome length file",
                    "format": "http://edamontology.org/format_2330",
                    "outputSource": "#main/star_generate_indices/chr_name_length",
                    "doc": "Chromosome length file",
                    "id": "#main/chrom_length"
                },
                {
                    "type": "Directory",
                    "label": "STAR indices folder",
                    "doc": "Folder which includes all STAR generated indices files",
                    "outputSource": "#main/star_generate_indices/indices",
                    "id": "#main/star_indices"
                }
            ],
            "steps": [
                {
                    "run": "#star-genomegenerate.cwl",
                    "in": [
                        {
                            "source": "#main/genome_chr_bin_n_bits",
                            "id": "#main/star_generate_indices/genome_chr_bin_n_bits"
                        },
                        {
                            "default": ".",
                            "id": "#main/star_generate_indices/genome_dir"
                        },
                        {
                            "source": "#main/fasta",
                            "id": "#main/star_generate_indices/genome_fasta_files"
                        },
                        {
                            "source": "#main/genome_sa_index_n_bases",
                            "id": "#main/star_generate_indices/genome_sa_index_n_bases"
                        },
                        {
                            "source": "#main/genome_sa_sparse_d",
                            "id": "#main/star_generate_indices/genome_sa_sparse_d"
                        },
                        {
                            "source": "#main/limit_genome_generate_ram",
                            "id": "#main/star_generate_indices/limit_genome_generate_ram"
                        },
                        {
                            "source": "#main/annotation_gtf",
                            "id": "#main/star_generate_indices/sjdb_gtf_file"
                        },
                        {
                            "source": "#main/threads",
                            "id": "#main/star_generate_indices/threads"
                        }
                    ],
                    "out": [
                        "#main/star_generate_indices/indices",
                        "#main/star_generate_indices/chr_name_length"
                    ],
                    "id": "#main/star_generate_indices"
                }
            ],
            "label": "Generate genome index STAR RNA",
            "doc": "Workflow makes indices for [STAR](https://github.com/alexdobin/STAR) v2.5.3a (03/17/2017) PMID: [23104886](https://www.ncbi.nlm.nih.gov/pubmed/23104886).\n\nIt performs the following steps:\n1. Runs `STAR --runMode genomeGenerate` to generate indices, based on [FASTA](http://zhanglab.ccmb.med.umich.edu/FASTA/) and [GTF](http://mblab.wustl.edu/GTF2.html) input files, returns results as an array of files\n2. Transforms array of files into [Direcotry](http://www.commonwl.org/v1.0/CommandLineTool.html#Directory) data type\n3. Separates *chrNameLength.txt* file as an output\n",
            "id": "#main",
            "http://schema.org/name": "Generate genome index STAR RNA",
            "http://schema.org/alternateName": "Generates indices for STAR v2.5.3a (03/17/2017)",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/barski-lab/workflows/master/workflows/scidap/star-index.cwl",
            "http://schema.org/codeRepository": "https://github.com/barski-lab/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:michael.kotliar@cchmc.org",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "id": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        },
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Andrey Kartashov",
                                            "http://schema.org/email": "mailto:Andrey.Kartashov@cchmc.org",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "$import": "#0000-0001-9102-5681"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ]
        }
    ],
    "cwlVersion": "v1.0",
    "$schemas": [
        "http://schema.org/docs/schema_org_rdfa.html"
    ],
    "$namespaces": {
        "s": "http://schema.org/"
    }
}
